Crate embedded_executor_macros

Crate embedded_executor_macros 

Proc macros for the embedded-executor crate.

Provides #[main] and #[test] attributes for running async functions with a specified IO implementation.

Attribute Macros

main
Marks an async function as the main entry point.
test
Marks an async function as a test.